import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import Qt.labs.qmlmodels

Window {
  width: 640
  height: 480
  visible: true

  ColumnLayout {
    anchors.fill: parent

    RowLayout {
      Button {
        text: "reset model"
        Layout.preferredHeight: 25
        onClicked: {
          tableview.model = null
          tableview.model = tableModel
          tableview.toggleColor = !tableview.toggleColor
        }
      }
    }

    TableView {
      id: tableview
      clip: true
      boundsBehavior: Flickable.StopAtBounds
      pixelAligned: true
      Layout.fillHeight: true
      Layout.fillWidth: true

      property bool toggleColor: false
      readonly property color backgroundColor: toggleColor ? "#5500ff00" : "#55ff0000"

      contentHeight: 20 * tableview.rows
      contentWidth: 100
      columnWidthProvider: function(column) {
        return 100
      }
      rowHeightProvider: function(row) {
        return 20
      }

      model: TableModel {
        id: tableModel
        TableModelColumn { display: "rowId" }

        Component.onCompleted: {
          for (let i = 0; i < 100000; ++i) {
            tableModel.appendRow({ rowId: i })
          }
        }
      }

      delegate: Rectangle {
        color: TableView.view.backgroundColor
        Text {
          text: model.display
        }
      }

      ScrollBar.vertical: ScrollBar {
        policy: ScrollBar.AlwaysOn
      }
    }

    Timer {
      interval: 200
      running: true
      onTriggered: {
        tableview.positionViewAtRow(99999, Qt.AlignBottom, 0)
      }
    }
  }
}
